@@ -36,16 +36,20 @@ def connection_queue(defer_connections=False):
         return
     establish_queued_connections()
 
+
 def establish_queued_connections():
     global __DEFER_CONNECTIONS__
     global __CONNECTION_QUEUE__
     if __CONNECTION_QUEUE__ is None:
         return
     try:
-        while not len(__CONNECTION_QUEUE__) == 0:
+        while (__CONNECTION_QUEUE__ is not None and
+               len(__CONNECTION_QUEUE__) > 0):
             channel = __CONNECTION_QUEUE__.popleft()
             establish_connection_immediately(channel)
             QApplication.instance().processEvents()
+    except IndexError:
+        pass
     finally:
         __CONNECTION_QUEUE__ = None
         __DEFER_CONNECTIONS__ = False
