@@ -20,16 +20,6 @@ def test_construct():
     Expecations:
     The default values are assigned to the attributes correctly.
     """
-    pydm_colormap = PyDMColorMap()
-
-    for (name, data) in ((PyDMColorMap.Magma, np.array(_magma_data)),
-                         (PyDMColorMap.Inferno, np.array(_inferno_data)),
-                         (PyDMColorMap.Plasma, np.array(_plasma_data)),
-                         (PyDMColorMap.Viridis, np.array(_viridis_data)),
-                         (PyDMColorMap.Jet, np.array(_jet_data)),
-                         (PyDMColorMap.Monochrome, np.array(_monochrome_data)),
-                         (PyDMColorMap.Hot, np.array(_hot_data))):
-        assert np.array_equal(cmaps[name], data)
 
     assert np.array_equal(magma, cmaps[PyDMColorMap.Magma])
     assert np.array_equal(inferno, cmaps[PyDMColorMap.Inferno])
